@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef GCONF_GCONF_INTERNALS_H
@@ -29,11 +29,9 @@
 #include <config.h>
 #include <libintl.h>
 
-#define _(String) dgettext (GETTEXT_PACKAGE, String)
-#define N_(String) (String)
-
 #include <glib.h>
 #include <glib/gstdio.h>
+#include <glib/gi18n-lib.h>
 #include "gconf-error.h"
 #include "gconf-value.h"
 #include "gconf-engine.h"
@@ -90,17 +88,6 @@ const char *_gconf_win32_get_home_dir (void);
 gchar*       gconf_key_directory  (const gchar* key);
 const gchar* gconf_key_key        (const gchar* key);
 
-/* These file tests are in libgnome, I cut-and-pasted them */
-enum {
-  GCONF_FILE_EXISTS=(1<<0)|(1<<1)|(1<<2), /*any type of file*/
-  GCONF_FILE_ISFILE=1<<0,
-  GCONF_FILE_ISLINK=1<<1,
-  GCONF_FILE_ISDIR=1<<2
-};
-
-gboolean gconf_file_test   (const gchar* filename, int test);
-gboolean gconf_file_exists (const gchar* filename);
-
 GConfValue*  gconf_value_from_corba_value            (const ConfigValue *value);
 ConfigValue* gconf_corba_value_from_gconf_value      (const GConfValue  *value);
 void         gconf_fill_corba_value_from_gconf_value (const GConfValue  *value,
@@ -281,13 +268,6 @@ gboolean gconf_CORBA_Object_equal (gconstpointer a,
                                    gconstpointer b);
 guint    gconf_CORBA_Object_hash  (gconstpointer key);
 
-
-/* FIXME move to public eventually */
-gboolean    gconf_entry_equal (const GConfEntry *a,
-                               const GConfEntry *b);
-int         gconf_value_compare (const GConfValue *value_a,
-                                 const GConfValue *value_b);
-
 GConfValue* gconf_schema_steal_default_value (GConfSchema *schema);
 
 void gconf_value_set_string_nocopy (GConfValue *value,
