@@ -13,13 +13,15 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
+#include <config.h>
 #include "gconf-locale.h"
 #include "gconf-internals.h"
 #include <sys/time.h>
+#include <time.h>
 #include <string.h>
 
 static void
@@ -369,7 +371,7 @@ gconf_split_locale               (const gchar* locale)
   g_free (orig_category_memory);
   
   if (!c_locale_defined)
-    list = g_slist_append (list, "C");
+    list = g_slist_append (list, g_strdup ("C"));
 
   {
     /* Convert list to a string vector */
